summaryrefslogtreecommitdiff
path: root/test/lit/lit.cfg.py
diff options
context:
space:
mode:
Diffstat (limited to 'test/lit/lit.cfg.py')
-rw-r--r--test/lit/lit.cfg.py9
1 files changed, 5 insertions, 4 deletions
diff --git a/test/lit/lit.cfg.py b/test/lit/lit.cfg.py
index 60ba1ced6..bc034b349 100644
--- a/test/lit/lit.cfg.py
+++ b/test/lit/lit.cfg.py
@@ -15,7 +15,8 @@ for tool_file in os.listdir(bin_dir):
tool = tool_file[:-4] if tool_file.endswith('.exe') else tool_file
config.substitutions.append((tool, tool_path))
-# Also make the `not` command available
-not_file = config.binaryen_src_root + '/scripts/not.py'
-python = sys.executable.replace('\\', '/')
-config.substitutions.append(('not', python + ' ' + not_file))
+# Also make the `not` and `foreach` commands available
+for tool in ('not', 'foreach'):
+ tool_file = config.binaryen_src_root + '/scripts/' + tool + '.py'
+ python = sys.executable.replace('\\', '/')
+ config.substitutions.append((tool, python + ' ' + tool_file))